@@ -1116,7 +1116,8 @@ draw_label_text (NautilusIconCanvasItem *item,
 		x = text_rect.x0 + ((text_rect.x1 - text_rect.x0) - max_text_width) / 2;
 	}
 	
-	if (have_editable) {
+	if (have_editable &&
+	    !details->is_renaming) {
 		state = GTK_STATE_FLAG_NORMAL;
 
 		if (prelight_label && item->details->is_prelit) {
@@ -1142,7 +1143,8 @@ draw_label_text (NautilusIconCanvasItem *item,
 		gtk_style_context_restore (context);
 	}
 
-	if (have_additional) {
+	if (have_additional &&
+	    !details->is_renaming) {
 		state = GTK_STATE_FLAG_NORMAL;
 
 		if (needs_highlight && gtk_widget_has_focus (GTK_WIDGET (container))) {
@@ -1409,12 +1411,22 @@ draw_embedded_text (NautilusIconCanvasItem *item,
 	gtk_style_context_save (style_context);
 	gtk_style_context_add_class (style_context, "icon-embedded-text");
 
+	cairo_save (cr);
+
+	cairo_rectangle (cr,
+			 x + item->details->embedded_text_rect.x,
+			 y + item->details->embedded_text_rect.y,
+			 item->details->embedded_text_rect.width,
+			 item->details->embedded_text_rect.height);
+	cairo_clip (cr);
+
 	gtk_render_layout (style_context, cr,
 			   x + item->details->embedded_text_rect.x,
 			   y + item->details->embedded_text_rect.y,
 			   layout);
 
 	gtk_style_context_restore (style_context);
+	cairo_restore (cr);
 }
 
 /* Draw the icon item for non-anti-aliased mode. */
