@@ -30,16 +30,17 @@
 
 G_BEGIN_DECLS
 
-#define NAUTILUS_TYPE_ICON_CANVAS_ITEM \
-	(nautilus_icon_canvas_item_get_type ())
+#define NAUTILUS_TYPE_ICON_CANVAS_ITEM nautilus_icon_canvas_item_get_type()
 #define NAUTILUS_ICON_CANVAS_ITEM(obj) \
-	(GTK_CHECK_CAST ((obj), NAUTILUS_TYPE_ICON_CANVAS_ITEM, NautilusIconCanvasItem))
+  (G_TYPE_CHECK_INSTANCE_CAST ((obj), NAUTILUS_TYPE_ICON_CANVAS_ITEM, NautilusIconCanvasItem))
 #define NAUTILUS_ICON_CANVAS_ITEM_CLASS(klass) \
-	(GTK_CHECK_CLASS_CAST ((klass), NAUTILUS_TYPE_ICON_CANVAS_ITEM, NautilusIconCanvasItemClass))
+  (G_TYPE_CHECK_CLASS_CAST ((klass), NAUTILUS_TYPE_ICON_CANVAS_ITEM, NautilusIconCanvasItemClass))
 #define NAUTILUS_IS_ICON_CANVAS_ITEM(obj) \
-        (GTK_CHECK_TYPE ((obj), NAUTILUS_TYPE_ICON_CANVAS_ITEM))
+  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NAUTILUS_TYPE_ICON_CANVAS_ITEM))
 #define NAUTILUS_IS_ICON_CANVAS_ITEM_CLASS(klass) \
-	(GTK_CHECK_CLASS_TYPE ((klass),	NAUTILUS_TYPE_ICON_CANVAS_ITEM))
+  (G_TYPE_CHECK_CLASS_TYPE ((klass), NAUTILUS_TYPE_ICON_CANVAS_ITEM))
+#define NAUTILUS_ICON_CANVAS_ITEM_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_CLASS ((obj), NAUTILUS_TYPE_ICON_CANVAS_ITEM, NautilusIconCanvasItemClass))
 
 typedef struct NautilusIconCanvasItem NautilusIconCanvasItem;
 typedef struct NautilusIconCanvasItemClass NautilusIconCanvasItemClass;
@@ -68,9 +69,7 @@ GType       nautilus_icon_canvas_item_get_type                 (void);
 /* attributes */
 void        nautilus_icon_canvas_item_set_image                (NautilusIconCanvasItem       *item,
 								GdkPixbuf                    *image);
-GdkPixmap * nautilus_icon_canvas_item_get_image                (NautilusIconCanvasItem       *item,
-								GdkBitmap                   **mask,
-								GdkColormap		     *colormap);
+cairo_surface_t* nautilus_icon_canvas_item_get_drag_surface    (NautilusIconCanvasItem       *item);
 void        nautilus_icon_canvas_item_set_emblems              (NautilusIconCanvasItem       *item,
 								GList                        *emblem_pixbufs);
 void        nautilus_icon_canvas_item_set_show_stretch_handles (NautilusIconCanvasItem       *item,
