@@ -203,15 +203,6 @@ struct NautilusIconContainerDetails {
 	/* font sizes used to draw labels */
 	int font_size_table[NAUTILUS_ZOOM_LEVEL_LARGEST + 1];
 
-	/* pixbuf and color for label highlighting */
-	GdkRGBA    highlight_color_rgba;
-	GdkRGBA    active_color_rgba;
-	GdkRGBA    normal_color_rgba;
-	GdkRGBA    prelight_color_rgba;
-
-	/* colors for text labels */
-	GdkRGBA label_colors [LAST_LABEL_COLOR];
-	
 	/* State used so arrow keys don't wander if icons aren't lined up.
 	 */
 	int arrow_key_start_x;
@@ -281,7 +272,6 @@ struct NautilusIconContainerDetails {
 	time_t layout_timestamp;
 
 	/* interactive search */
-	gboolean disable_popdown;
 	gboolean imcontext_changed;
 	int selected_iter;
 	GtkWidget *search_window;
@@ -310,19 +300,9 @@ char *        nautilus_icon_container_get_icon_drop_target_uri    (NautilusIconC
 void          nautilus_icon_container_update_icon                 (NautilusIconContainer *container,
 								   NautilusIcon          *icon);
 gboolean      nautilus_icon_container_has_stored_icon_positions   (NautilusIconContainer *container);
-gboolean      nautilus_icon_container_emit_preview_signal         (NautilusIconContainer *view,
-								   NautilusIcon          *icon,
-								   gboolean               start_flag);
 gboolean      nautilus_icon_container_scroll                      (NautilusIconContainer *container,
 								   int                    delta_x,
 								   int                    delta_y);
 void          nautilus_icon_container_update_scroll_region        (NautilusIconContainer *container);
 
-/* label color for items */
-void          nautilus_icon_container_get_label_color             (NautilusIconContainer *container,
-								   GdkRGBA               *color,
-								   gboolean               first_line,
-								   gboolean               needs_highlight,
-								   gboolean		  is_prelit);
-
 #endif /* NAUTILUS_ICON_CONTAINER_PRIVATE_H */
