@@ -31,16 +31,16 @@
 #include <libnautilus-private/nautilus-file-utilities.h>
 #include <libnautilus-private/nautilus-file.h>
 #include <libnautilus-private/nautilus-icon-names.h>
-#include <eel/eel-glib-extensions.h>
-#include <eel/eel-string.h>
+
 #include <gio/gio.h>
+#include <string.h>
 
 #define MAX_BOOKMARK_LENGTH 80
 #define LOAD_JOB 1
 #define SAVE_JOB 2
 
 enum {
-	CONTENTS_CHANGED,
+	CHANGED,
 	LAST_SIGNAL
 };
 
@@ -59,51 +59,20 @@ static NautilusBookmark *
 new_bookmark_from_uri (const char *uri, const char *label)
 {
 	NautilusBookmark *new_bookmark;
-	NautilusFile *file;
-	char *name;
-	GIcon *icon;
-	gboolean has_label;
 	GFile *location;
-	gboolean native;
 
 	location = NULL;
 	if (uri) {
 		location = g_file_new_for_uri (uri);
 	}
 	
-	has_label = FALSE;
-	if (!label) { 
-		name = nautilus_compute_title_for_location (location);
-	} else {
-		name = g_strdup (label);
-		has_label = TRUE;
-	}
-
 	new_bookmark = NULL;
-	
-	if (uri) {
-		native = g_file_is_native (location);
-		file = nautilus_file_get (location);
-
-		icon = NULL;
-		if (nautilus_file_check_if_ready (file,
-						  NAUTILUS_FILE_ATTRIBUTES_FOR_ICON)) {
-			icon = nautilus_file_get_gicon (file, 0);
-		}
-		nautilus_file_unref (file);
-		
-		if (icon == NULL) {
-			icon = native ? g_themed_icon_new (NAUTILUS_ICON_FOLDER) :
-				g_themed_icon_new (NAUTILUS_ICON_FOLDER_REMOTE);
-		}
-
-		new_bookmark = nautilus_bookmark_new (location, name, has_label, icon);
-
-		g_object_unref (icon);
 
+	if (location) {
+		new_bookmark = nautilus_bookmark_new (location, label, NULL);
+		g_object_unref (location);
 	}
-	g_free (name);
-	g_object_unref (location);
+
 	return new_bookmark;
 }
 
@@ -132,10 +101,19 @@ bookmark_in_list_changed_callback (NautilusBookmark     *bookmark,
 	g_assert (NAUTILUS_IS_BOOKMARK (bookmark));
 	g_assert (NAUTILUS_IS_BOOKMARK_LIST (bookmarks));
 
-	/* Save changes so we'll have the good icon next time. */
+	/* save changes to the list */
 	nautilus_bookmark_list_save_file (bookmarks);
 }
 
+static void
+bookmark_in_list_notify (GObject *object,
+			 GParamSpec *pspec,
+			 NautilusBookmarkList *bookmarks)
+{
+	/* emit the changed signal without saving, as only appearance properties changed */
+	g_signal_emit (bookmarks, signals[CHANGED], 0);
+}
+
 static void
 stop_monitoring_bookmark (NautilusBookmarkList *bookmarks,
 			  NautilusBookmark     *bookmark)
@@ -159,7 +137,7 @@ static void
 clear (NautilusBookmarkList *bookmarks)
 {
 	g_list_foreach (bookmarks->list, stop_monitoring_one, bookmarks);
-	eel_g_object_list_free (bookmarks->list);
+	g_list_free_full (bookmarks->list, g_object_unref);
 	bookmarks->list = NULL;
 }
 
@@ -207,12 +185,12 @@ nautilus_bookmark_list_class_init (NautilusBookmarkListClass *class)
 	object_class->finalize = do_finalize;
 	object_class->constructor = do_constructor;
 
-	signals[CONTENTS_CHANGED] =
-		g_signal_new ("contents_changed",
+	signals[CHANGED] =
+		g_signal_new ("changed",
 		              G_TYPE_FROM_CLASS (object_class),
 		              G_SIGNAL_RUN_LAST,
 		              G_STRUCT_OFFSET (NautilusBookmarkListClass, 
-						   contents_changed),
+					       changed),
 		              NULL, NULL,
 		              g_cclosure_marshal_VOID__VOID,
 		              G_TYPE_NONE, 0);
@@ -258,8 +236,12 @@ insert_bookmark_internal (NautilusBookmarkList *bookmarks,
 {
 	bookmarks->list = g_list_insert (bookmarks->list, bookmark, index);
 
-	g_signal_connect_object (bookmark, "contents_changed",
+	g_signal_connect_object (bookmark, "contents-changed",
 				 G_CALLBACK (bookmark_in_list_changed_callback), bookmarks, 0);
+	g_signal_connect_object (bookmark, "notify::icon",
+				 G_CALLBACK (bookmark_in_list_notify), bookmarks, 0);
+	g_signal_connect_object (bookmark, "notify::name",
+				 G_CALLBACK (bookmark_in_list_notify), bookmarks, 0);
 }
 
 /**
@@ -391,7 +373,7 @@ nautilus_bookmark_list_delete_items_with_uri (NautilusBookmarkList *bookmarks,
 		next = node->next;
 
 		bookmark_uri = nautilus_bookmark_get_uri (NAUTILUS_BOOKMARK (node->data));
-		if (eel_strcmp (bookmark_uri, uri) == 0) {
+		if (g_strcmp0 (bookmark_uri, uri) == 0) {
 			bookmarks->list = g_list_remove_link (bookmarks->list, node);
 			stop_monitoring_bookmark (bookmarks, NAUTILUS_BOOKMARK (node->data));
 			g_object_unref (node->data);
@@ -518,7 +500,7 @@ load_file_finish (NautilusBookmarkList *bookmarks,
       		g_free (contents);
        		g_strfreev (lines);
 
-		g_signal_emit (bookmarks, signals[CONTENTS_CHANGED], 0);
+		g_signal_emit (bookmarks, signals[CHANGED], 0);
 	} else if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_NOT_FOUND)) {
 		g_warning ("Could not load bookmark file: %s\n", error->message);
 		g_error_free (error);
@@ -595,13 +577,13 @@ save_file_async (NautilusBookmarkList *bookmarks,
 
 		/* make sure we save label if it has one for compatibility with GTK 2.7 and 2.8 */
 		if (nautilus_bookmark_get_has_custom_name (bookmark)) {
-			char *label, *uri;
+			const char *label;
+			char *uri;
 			label = nautilus_bookmark_get_name (bookmark);
 			uri = nautilus_bookmark_get_uri (bookmark);
 			g_string_append_printf (bookmark_string,
 						"%s %s\n", uri, label);
 			g_free (uri);
-			g_free (label);
 		} else {
 			char *uri;
 			uri = nautilus_bookmark_get_uri (bookmark);
@@ -686,7 +668,7 @@ nautilus_bookmark_list_load_file (NautilusBookmarkList *bookmarks)
 static void
 nautilus_bookmark_list_save_file (NautilusBookmarkList *bookmarks)
 {
-	g_signal_emit (bookmarks, signals[CONTENTS_CHANGED], 0);
+	g_signal_emit (bookmarks, signals[CHANGED], 0);
 
 	g_queue_push_head (bookmarks->pending_ops, GINT_TO_POINTER (SAVE_JOB));
 
