@@ -49,7 +49,6 @@
 #define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_DATE_FORMAT_WIDGET "date_format_combobox"
 #define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_PREVIEW_TEXT_WIDGET "preview_text_combobox"
 #define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_PREVIEW_IMAGE_WIDGET "preview_image_combobox"
-#define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_PREVIEW_SOUND_WIDGET "preview_sound_combobox"
 #define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_PREVIEW_FOLDER_WIDGET "preview_folder_combobox"
 
 /* bool preferences */
@@ -189,7 +188,7 @@ preferences_show_help (GtkWindow *parent,
 	g_assert (helpfile != NULL);
 	g_assert (sect_id != NULL);
 
-	help_string = g_strdup_printf ("ghelp:%s#%s", helpfile, sect_id);
+	help_string = g_strdup_printf ("help:%s/%s", helpfile, sect_id);
 
 	gtk_show_uri (gtk_window_get_screen (parent),
 		      help_string, gtk_get_current_event_time (),
@@ -225,25 +224,22 @@ nautilus_file_management_properties_dialog_response_cb (GtkDialog *parent,
 		switch (gtk_notebook_get_current_page (GTK_NOTEBOOK (gtk_builder_get_object (builder, "notebook1")))) {
 		default:
 		case 0:
-			section = "gosnautilus-438";
+			section = "nautilus-views";
 			break;
 		case 1:
-			section = "gosnautilus-56";
+			section = "nautilus-behavior";
 			break;
 		case 2:
-			section = "gosnautilus-439";
+			section = "nautilus-display";
 			break;
 		case 3:
-			section = "gosnautilus-490";
+			section = "nautilus-list";
 			break;
 		case 4:
-			section = "gosnautilus-60";
-			break;
-		case 5:
-			section = "gosnautilus-61";
+			section = "nautilus-preview";
 			break;
 		}
-		preferences_show_help (GTK_WINDOW (parent), "user-guide", section);
+		preferences_show_help (GTK_WINDOW (parent), "gnome-help", section);
 	} else if (response_id == GTK_RESPONSE_CLOSE) {
 		gtk_widget_destroy (GTK_WIDGET (parent));
 	}
@@ -651,48 +647,38 @@ bind_builder_uint_enum (GtkBuilder *builder,
 				      binding, g_free);
 }
 
-typedef struct {
-	GtkWidget *button;
-	const char *value;
-	const char *key;
-	GSettings *settings;
-} RadioBinding;
-
-static void
-radio_binding_setting_changed (GSettings   *settings,
-			       const gchar *key,
-			       gpointer     user_data)
+static GVariant *
+radio_mapping_set (const GValue *gvalue,
+		   const GVariantType *expected_type,
+		   gpointer user_data)
 {
-	RadioBinding *binding = user_data;
-	char *value;
+	const gchar *widget_value = user_data;
+	GVariant *retval = NULL;
 
-	value = g_settings_get_string (settings, key);
-
-	if (strcmp (value, binding->value) == 0) {
-		/* This will unset the currently active, no need
-		   to do that manually */
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (binding->button), TRUE);
+	if (g_value_get_boolean (gvalue)) {
+		retval = g_variant_new_string (widget_value);
 	}
-	g_free (value);
+
+	return retval;
 }
 
-static void
-radio_binding_button_toggled (GtkToggleButton *toggle_button,
-			      RadioBinding *binding)
+static gboolean
+radio_mapping_get (GValue *gvalue,
+		   GVariant *variant,
+		   gpointer user_data)
 {
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (binding->button))) {
-		g_settings_set_string (binding->settings, binding->key, binding->value);
+	const gchar *widget_value = user_data;
+	const gchar *value;
+
+	value = g_variant_get_string (variant, NULL);
+
+	if (g_strcmp0 (value, widget_value) == 0) {
+		g_value_set_boolean (gvalue, TRUE);
+	} else {
+		g_value_set_boolean (gvalue, FALSE);
 	}
-}
 
-static void
-free_radio_binding (gpointer	 data,
-		    GClosure	*closure)
-{
-	RadioBinding *binding = data;
-
-	g_object_unref (binding->settings);
-	g_free (binding);
+	return TRUE;
 }
 
 static void
@@ -704,27 +690,15 @@ bind_builder_radio (GtkBuilder *builder,
 {
 	GtkWidget *button;
 	int i;
-	char *detailed_signal;
-	RadioBinding *binding;
-
-	detailed_signal = g_strdup_printf ("changed::%s", prefs);
 
 	for (i = 0; widget_names[i] != NULL; i++) {
 		button = GTK_WIDGET (gtk_builder_get_object (builder, widget_names[i]));
 
-		binding = g_new (RadioBinding, 1);
-		binding->button = button;
-		binding->value = values[i];
-		binding->key = prefs;
-		binding->settings = g_object_ref (settings);
-
-		g_signal_connect (settings, detailed_signal,
-				  G_CALLBACK(radio_binding_setting_changed),
-				  binding);
-
-		g_signal_connect_data (G_OBJECT (button), "toggled",
-				       G_CALLBACK (radio_binding_button_toggled),
-				       binding, free_radio_binding, 0);
+		g_settings_bind_with_mapping (settings, prefs,
+					      button, "active",
+					      G_SETTINGS_BIND_DEFAULT,
+					      radio_mapping_get, radio_mapping_set,
+					      (gpointer) values[i], NULL);
 	}
 }
 
@@ -743,7 +717,7 @@ nautilus_file_management_properties_dialog_setup (GtkBuilder *builder, GtkWindow
 							       3);
 	nautilus_file_management_properties_size_group_create (builder,
 							       "preview_label",
-							       5);
+							       4);
 	create_date_format_menu (builder);
 
 	/* setup preferences */
@@ -802,10 +776,6 @@ nautilus_file_management_properties_dialog_setup (GtkBuilder *builder, GtkWindow
 			   NAUTILUS_FILE_MANAGEMENT_PROPERTIES_PREVIEW_IMAGE_WIDGET,
 			   NAUTILUS_PREFERENCES_SHOW_IMAGE_FILE_THUMBNAILS,
 			   (const char **) preview_values);
-	bind_builder_enum (builder, nautilus_preferences,
-			   NAUTILUS_FILE_MANAGEMENT_PROPERTIES_PREVIEW_SOUND_WIDGET,
-			   NAUTILUS_PREFERENCES_PREVIEW_SOUND,
-			   (const char **) preview_values);
 	bind_builder_enum (builder, nautilus_preferences,
 			   NAUTILUS_FILE_MANAGEMENT_PROPERTIES_PREVIEW_FOLDER_WIDGET,
 			   NAUTILUS_PREFERENCES_SHOW_DIRECTORY_ITEM_COUNTS,
