@@ -229,26 +229,34 @@ get_eject_icon (NautilusPlacesSidebar *sidebar,
 	icon_info = gtk_icon_theme_lookup_by_gicon (icon_theme, icon, icon_size, 0);
 
 	style = gtk_widget_get_style_context (GTK_WIDGET (sidebar));
-	state = gtk_widget_get_state_flags (GTK_WIDGET (sidebar));
-
 	gtk_style_context_save (style);
-	gtk_style_context_add_class (style, GTK_STYLE_CLASS_IMAGE);
 
-	if (highlighted) {
-		state |= GTK_STATE_FLAG_PRELIGHT;
+	if (icon_info != NULL) {
+		state = gtk_widget_get_state_flags (GTK_WIDGET (sidebar));
+		gtk_style_context_add_class (style, GTK_STYLE_CLASS_IMAGE);
+
+		if (highlighted) {
+			state |= GTK_STATE_FLAG_PRELIGHT;
+		}
+
+		gtk_style_context_set_state (style, state);
+
+		eject = gtk_icon_info_load_symbolic_for_context (icon_info,
+								 style,
+								 NULL,
+								 NULL);
+
+		gtk_icon_info_free (icon_info);
+	} else {
+		GtkIconSet *icon_set;
+
+		gtk_style_context_set_state (style, GTK_STATE_FLAG_NORMAL);
+		icon_set = gtk_style_context_lookup_icon_set (style, GTK_STOCK_MISSING_IMAGE);
+		eject = gtk_icon_set_render_icon_pixbuf (icon_set, style, GTK_ICON_SIZE_MENU);
 	}
 
-	gtk_style_context_set_state (style, state);
-
-	eject = gtk_icon_info_load_symbolic_for_context (icon_info,
-							 style,
-							 NULL,
-							 NULL);
-
 	gtk_style_context_restore (style);
-
 	g_object_unref (icon);
-	gtk_icon_info_free (icon_info);
 
 	return eject;
 }
@@ -457,6 +465,8 @@ update_places (NautilusPlacesSidebar *sidebar)
 	GList *network_mounts;
 	NautilusFile *file;
 
+	DEBUG ("Updating places sidebar");
+
 	model = NULL;
 	last_uri = NULL;
 	select_path = NULL;
@@ -2036,7 +2046,6 @@ unmount_done (gpointer data)
 	NautilusWindow *window;
 
 	window = data;
-	nautilus_window_set_initiated_unmount (window, FALSE);
 	g_object_unref (window);
 }
 
@@ -2045,7 +2054,6 @@ do_unmount (GMount *mount,
 	    NautilusPlacesSidebar *sidebar)
 {
 	if (mount != NULL) {
-		nautilus_window_set_initiated_unmount (sidebar->window, TRUE);
 		nautilus_file_operations_unmount_mount_full (NULL, mount, FALSE, TRUE,
 							     unmount_done,
 							     g_object_ref (sidebar->window));
@@ -2090,7 +2098,6 @@ drive_eject_cb (GObject *source_object,
 	char *name;
 
 	window = user_data;
-	nautilus_window_set_initiated_unmount (window, FALSE);
 	g_object_unref (window);
 
 	error = NULL;
@@ -2119,7 +2126,6 @@ volume_eject_cb (GObject *source_object,
 	char *name;
 
 	window = user_data;
-	nautilus_window_set_initiated_unmount (window, FALSE);
 	g_object_unref (window);
 
 	error = NULL;
@@ -2148,7 +2154,6 @@ mount_eject_cb (GObject *source_object,
 	char *name;
 
 	window = user_data;
-	nautilus_window_set_initiated_unmount (window, FALSE);
 	g_object_unref (window);
 
 	error = NULL;
@@ -2176,15 +2181,12 @@ do_eject (GMount *mount,
 
 	mount_op = gtk_mount_operation_new (GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (sidebar))));
 	if (mount != NULL) {
-		nautilus_window_set_initiated_unmount (sidebar->window, TRUE);
 		g_mount_eject_with_operation (mount, 0, mount_op, NULL, mount_eject_cb,
 					      g_object_ref (sidebar->window));
 	} else if (volume != NULL) {
-		nautilus_window_set_initiated_unmount (sidebar->window, TRUE);
 		g_volume_eject_with_operation (volume, 0, mount_op, NULL, volume_eject_cb,
 					      g_object_ref (sidebar->window));
 	} else if (drive != NULL) {
-		nautilus_window_set_initiated_unmount (sidebar->window, TRUE);
 		g_drive_eject_with_operation (drive, 0, mount_op, NULL, drive_eject_cb,
 					      g_object_ref (sidebar->window));
 	}
@@ -2392,7 +2394,6 @@ drive_stop_cb (GObject *source_object,
 	char *name;
 
 	window = user_data;
-	nautilus_window_set_initiated_unmount (window, FALSE);
 	g_object_unref (window);
 
 	error = NULL;
@@ -2429,7 +2430,6 @@ stop_shortcut_cb (GtkMenuItem           *item,
 		GMountOperation *mount_op;
 
 		mount_op = gtk_mount_operation_new (GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (sidebar))));
-		nautilus_window_set_initiated_unmount (sidebar->window, TRUE);
 		g_drive_stop (drive, G_MOUNT_UNMOUNT_NONE, mount_op, NULL, drive_stop_cb,
 			      g_object_ref (sidebar->window));
 		g_object_unref (mount_op);
@@ -2892,14 +2892,20 @@ bookmarks_button_press_event_cb (GtkWidget             *widget,
 		GtkTreeIter iter;
 		GtkTreeView *tree_view;
 		NautilusWindowOpenFlags flags = 0;
+		gboolean res;
 
 		tree_view = GTK_TREE_VIEW (widget);
 		g_assert (tree_view == sidebar->tree_view);
 
 		model = gtk_tree_view_get_model (tree_view);
 
-		gtk_tree_view_get_path_at_pos (tree_view, (int) event->x, (int) event->y, 
-					       &path, NULL, NULL, NULL);
+		res = gtk_tree_view_get_path_at_pos (tree_view, (int) event->x, (int) event->y, 
+						     &path, NULL, NULL, NULL);
+
+		if (!res) {
+			return FALSE;
+		}
+
 		gtk_tree_model_get_iter (model, &iter, path);
 
 		if (g_settings_get_boolean (nautilus_preferences,
@@ -3303,7 +3309,6 @@ nautilus_places_sidebar_dispose (GObject *object)
 	}
 
 	g_clear_object (&sidebar->store);
-	g_clear_object (&sidebar->volume_monitor);
 	g_clear_object (&sidebar->bookmarks);
 	g_clear_object (&sidebar->filter_model);
 
@@ -3321,6 +3326,29 @@ nautilus_places_sidebar_dispose (GObject *object)
 					      desktop_setting_changed_callback,
 					      sidebar);
 
+	if (sidebar->volume_monitor != NULL) {
+		g_signal_handlers_disconnect_by_func (sidebar->volume_monitor, 
+						      volume_added_callback, sidebar);
+		g_signal_handlers_disconnect_by_func (sidebar->volume_monitor, 
+						      volume_removed_callback, sidebar);
+		g_signal_handlers_disconnect_by_func (sidebar->volume_monitor, 
+						      volume_changed_callback, sidebar);
+		g_signal_handlers_disconnect_by_func (sidebar->volume_monitor, 
+						      mount_added_callback, sidebar);
+		g_signal_handlers_disconnect_by_func (sidebar->volume_monitor, 
+						      mount_removed_callback, sidebar);
+		g_signal_handlers_disconnect_by_func (sidebar->volume_monitor, 
+						      mount_changed_callback, sidebar);
+		g_signal_handlers_disconnect_by_func (sidebar->volume_monitor, 
+						      drive_disconnected_callback, sidebar);
+		g_signal_handlers_disconnect_by_func (sidebar->volume_monitor, 
+						      drive_connected_callback, sidebar);
+		g_signal_handlers_disconnect_by_func (sidebar->volume_monitor, 
+						      drive_changed_callback, sidebar);
+
+		g_clear_object (&sidebar->volume_monitor);
+	}
+
 	G_OBJECT_CLASS (nautilus_places_sidebar_parent_class)->dispose (object);
 }
 
