@@ -777,7 +777,7 @@ button_pressed_callback (GtkTreeView *treeview, GdkEventButton *event,
 		gtk_tree_view_set_cursor (view->details->tree_widget, cursor_path, NULL, FALSE);
 		gtk_tree_path_free (cursor_path);
 
-		return TRUE;
+		return FALSE;
 	} else if (event->button == 2 && event->type == GDK_BUTTON_PRESS) {
 		NautilusFile *file;
 		NautilusWindowOpenFlags flags = 0;
@@ -1028,7 +1028,7 @@ fm_tree_view_trash_cb (GtkWidget *menu_item,
 	nautilus_file_operations_trash_or_delete (list, 
 						  fm_tree_view_get_containing_window (view),
 						  NULL, NULL);
-	g_list_free_full (list, g_free);
+	g_list_free_full (list, g_object_unref);
 }
 
 static void
