@@ -29,20 +29,14 @@
 
 #include "nautilus-window.h"
 #include "nautilus-window-pane.h"
-#include "nautilus-navigation-window.h"
 
 void nautilus_window_manage_views_close_slot (NautilusWindowPane *pane,
                                               NautilusWindowSlot *slot);
 
 
 /* NautilusWindowInfo implementation: */
-void nautilus_window_report_load_underway     (NautilusWindow     *window,
-                                               NautilusView       *view);
-void nautilus_window_report_selection_changed (NautilusWindowInfo *window);
 void nautilus_window_report_view_failed       (NautilusWindow     *window,
                                                NautilusView       *view);
-void nautilus_window_report_load_complete     (NautilusWindow     *window,
-                                               NautilusView       *view);
 void nautilus_window_report_location_change   (NautilusWindow     *window);
 void nautilus_window_update_up_button         (NautilusWindow     *window);
 
