@@ -40,6 +40,9 @@
 #include <libnautilus-private/nautilus-global-preferences.h>
 #include <libnautilus-private/nautilus-entry.h>
 
+#define DEBUG_FLAG NAUTILUS_DEBUG_WINDOW
+#include <libnautilus-private/nautilus-debug.h>
+
 G_DEFINE_TYPE (NautilusWindowPane, nautilus_window_pane,
 	       G_TYPE_OBJECT)
 
@@ -150,30 +153,28 @@ search_bar_activate_callback (NautilusSearchBar *bar,
 
 	uri = nautilus_search_directory_generate_new_uri ();
 	location = g_file_new_for_uri (uri);
-	g_free (uri);
 
 	directory = nautilus_directory_get (location);
-
 	g_assert (NAUTILUS_IS_SEARCH_DIRECTORY (directory));
 
 	search_directory = NAUTILUS_SEARCH_DIRECTORY (directory);
-
 	query = nautilus_search_bar_get_query (NAUTILUS_SEARCH_BAR (pane->search_bar));
+
 	if (query != NULL) {
-		NautilusWindowSlot *slot = pane->active_slot;
-		if (!nautilus_search_directory_is_indexed (search_directory)) {
-			current_uri = nautilus_window_slot_get_location_uri (slot);
-			nautilus_query_set_location (query, current_uri);
-			g_free (current_uri);
-		}
+		current_uri = nautilus_window_slot_get_location_uri (pane->active_slot);
+
+		nautilus_query_set_location (query, current_uri);
 		nautilus_search_directory_set_query (search_directory, query);
+
+		g_free (current_uri);
 		g_object_unref (query);
 	}
 
 	nautilus_window_slot_go_to (pane->active_slot, location, FALSE);
 
 	nautilus_directory_unref (directory);
-	g_object_unref (location);
+	g_object_unref (location);	
+	g_free (uri);
 }
 
 static void
@@ -613,12 +614,10 @@ action_show_hide_search_callback (GtkAction *action,
 		GFile *location = NULL;
 
 		slot = pane->active_slot;
+		nautilus_window_pane_hide_search_bar (pane);
 
 		/* Use the location bar as the return location */
-		if (slot->query_editor == NULL){
-			location = nautilus_window_slot_get_location (slot);
-		/* Use the search location as the return location */
-		} else {
+		if (slot->query_editor != NULL) {
 			NautilusQuery *query;
 			char *uri;
 
@@ -631,17 +630,15 @@ action_show_hide_search_callback (GtkAction *action,
 				}
 				g_object_unref (query);
 			}
+
+			/* Last try: use the home directory as the return location */
+			if (location == NULL) {
+				location = g_file_new_for_path (g_get_home_dir ());
+			}
+
+			nautilus_window_go_to (window, location);
+			g_object_unref (location);
 		}
-
-		/* Last try: use the home directory as the return location */
-		if (location == NULL) {
-			location = g_file_new_for_path (g_get_home_dir ());
-		}
-
-		nautilus_window_go_to (window, location);
-		g_object_unref (location);
-
-		nautilus_window_pane_hide_search_bar (pane);
 	}
 }
 
@@ -663,7 +660,7 @@ nautilus_window_pane_setup (NautilusWindowPane *pane)
 	NautilusWindow *window;
 	GtkActionGroup *action_group;
 
-	pane->widget = gtk_vbox_new (FALSE, 0);
+	pane->widget = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	window = pane->window;
 
 	header_size_group = gtk_size_group_new (GTK_SIZE_GROUP_VERTICAL);
@@ -881,6 +878,22 @@ nautilus_window_pane_sync_location_widgets (NautilusWindowPane *pane)
 	}
 }
 
+static void
+toggle_toolbar_search_button (NautilusWindowPane *pane)
+{
+	GtkActionGroup *group;
+	GtkAction *action;
+
+	group = pane->action_group;
+	action = gtk_action_group_get_action (group, NAUTILUS_ACTION_SEARCH);
+
+	g_signal_handlers_block_by_func (action,
+					 action_show_hide_search_callback, pane);
+	gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), TRUE);
+	g_signal_handlers_unblock_by_func (action,
+					   action_show_hide_search_callback, pane);	
+}
+
 void
 nautilus_window_pane_sync_search_widgets (NautilusWindowPane *pane)
 {
@@ -896,10 +909,13 @@ nautilus_window_pane_sync_search_widgets (NautilusWindowPane *pane)
 		search_directory = NAUTILUS_SEARCH_DIRECTORY (directory);
 	}
 
-	if (search_directory != NULL &&
-	    !nautilus_search_directory_is_saved_search (search_directory)) {
-		nautilus_toolbar_set_show_search_bar (NAUTILUS_TOOLBAR (pane->tool_bar), TRUE);
-		pane->temporary_search_bar = FALSE;
+	if (search_directory != NULL) {
+		if (!nautilus_search_directory_is_saved_search (search_directory)) {
+			nautilus_toolbar_set_show_search_bar (NAUTILUS_TOOLBAR (pane->tool_bar), TRUE);
+			pane->temporary_search_bar = FALSE;
+		} else {
+			toggle_toolbar_search_button (pane);
+		}
 	} else {
 		search_bar_cancel_callback (pane->search_bar, pane);
 	}
@@ -913,6 +929,8 @@ nautilus_window_pane_slot_close (NautilusWindowPane *pane,
 {
 	NautilusWindowSlot *next_slot;
 
+	DEBUG ("Requesting to remove slot %p from pane %p", slot, pane);
+
 	if (pane->window) {
 		NautilusWindow *window;
 
@@ -925,20 +943,24 @@ nautilus_window_pane_slot_close (NautilusWindowPane *pane,
 
 		nautilus_window_close_slot (slot);
 
-		/* If that was the last slot in the active pane, close the pane or even the whole window. */
-		if (window->details->active_pane->slots == NULL) {
-			NautilusWindowPane *next_pane;
-			next_pane = nautilus_window_get_next_pane (window);
-			
-			/* If next_pane is non-NULL, we have more than one pane available. In this
-			 * case, close the current pane and switch to the next one. If there is
-			 * no next pane, close the window. */
-			if(next_pane) {
-				nautilus_window_close_pane (pane);
-				nautilus_window_set_active_pane (window, next_pane);
+		/* If that was the last slot in the pane, close the pane or even the whole window. */
+		if (pane->slots == NULL) {
+			if (nautilus_window_split_view_showing (window)) {
+				NautilusWindowPane *new_pane;
 
-				nautilus_window_update_show_hide_menu_items (window);
+				DEBUG ("Last slot removed from the pane %p, closing it", pane);
+				nautilus_window_close_pane (window, pane);
+
+				new_pane = window->details->panes->data;
+
+				if (new_pane->active_slot == NULL) {
+					new_pane->active_slot = get_first_inactive_slot (new_pane);
+				}
+
+				DEBUG ("Calling set_active_pane, new slot %p", new_pane->active_slot);
+				nautilus_window_set_active_pane (window, new_pane);
 			} else {
+				DEBUG ("Last slot removed from the last pane, close the window");
 				nautilus_window_close (window);
 			}
 		}
