@@ -700,6 +700,16 @@ free_stored_viewers (NautilusWindow *window)
 	window->details->extra_viewer = NULL;
 }
 
+static void
+destroy_panes_foreach (gpointer data,
+		       gpointer user_data)
+{
+	NautilusWindowPane *pane = data;
+	NautilusWindow *window = user_data;
+
+	nautilus_window_close_pane (window, pane);
+}
+
 static void
 nautilus_window_destroy (GtkWidget *object)
 {
@@ -708,12 +718,14 @@ nautilus_window_destroy (GtkWidget *object)
 
 	window = NAUTILUS_WINDOW (object);
 
+	DEBUG ("Destroying window");
+
 	window->details->content_paned = NULL;
 	window->details->split_view_hpane = NULL;
 
 	/* close all panes safely */
 	panes_copy = g_list_copy (window->details->panes);
-	g_list_foreach (panes_copy, (GFunc) nautilus_window_close_pane, NULL);
+	g_list_foreach (panes_copy, (GFunc) destroy_panes_foreach, window);
 	g_list_free (panes_copy);
 
 	/* the panes list should now be empty */
@@ -738,7 +750,7 @@ nautilus_window_finalize (GObject *object)
 	g_free (window->details->sidebar_id);
 	g_clear_object (&window->details->nav_state);
 
-	nautilus_window_remove_trash_monitor_callback (window);
+	nautilus_window_finalize_menus (window);
 	free_stored_viewers (window);
 
 	if (window->details->bookmark_list != NULL) {
@@ -883,13 +895,10 @@ nautilus_window_open_slot (NautilusWindowPane *pane,
 }
 
 void
-nautilus_window_close_pane (NautilusWindowPane *pane)
+nautilus_window_close_pane (NautilusWindow *window,
+			    NautilusWindowPane *pane)
 {
-	NautilusWindow *window;
-
 	g_assert (NAUTILUS_IS_WINDOW_PANE (pane));
-	g_assert (NAUTILUS_IS_WINDOW (pane->window));
-	g_assert (g_list_find (pane->window->details->panes, pane) != NULL);
 
 	while (pane->slots != NULL) {
 		NautilusWindowSlot *slot = pane->slots->data;
@@ -897,10 +906,8 @@ nautilus_window_close_pane (NautilusWindowPane *pane)
 		nautilus_window_close_slot (slot);
 	}
 
-	window = pane->window;
-
 	/* If the pane was active, set it to NULL. The caller is responsible
-	 * for setting a new active pane with nautilus_window_pane_switch_to()
+	 * for setting a new active pane with nautilus_window_set_active_pane()
 	 * if it wants to continue using the window. */
 	if (window->details->active_pane == pane) {
 		window->details->active_pane = NULL;
@@ -922,6 +929,8 @@ nautilus_window_close_slot (NautilusWindowSlot *slot)
 	g_assert (NAUTILUS_IS_WINDOW_PANE(slot->pane));
 	g_assert (g_list_find (slot->pane->slots, slot) != NULL);
 
+	DEBUG ("Closing slot %p", slot);
+
 	/* save pane because slot is not valid anymore after this call */
 	pane = slot->pane;
 	notebook = GTK_NOTEBOOK (pane->notebook);
@@ -972,6 +981,9 @@ nautilus_window_set_active_pane (NautilusWindow *window,
 				 NautilusWindowPane *new_pane)
 {
 	g_assert (NAUTILUS_IS_WINDOW_PANE (new_pane));
+
+	DEBUG ("Setting new pane %p as active", new_pane);
+
 	if (new_pane->active_slot) {
 		nautilus_window_set_active_slot (window, new_pane->active_slot);
 	} else if (new_pane != window->details->active_pane) {
@@ -989,6 +1001,8 @@ nautilus_window_set_active_slot (NautilusWindow *window, NautilusWindowSlot *new
 
 	g_assert (NAUTILUS_IS_WINDOW (window));
 
+	DEBUG ("Setting new slot %p as active", new_slot);
+
 	if (new_slot) {
 		g_assert (NAUTILUS_IS_WINDOW_SLOT (new_slot));
 		g_assert (NAUTILUS_IS_WINDOW_PANE (new_slot->pane));
@@ -2186,7 +2200,7 @@ nautilus_window_split_view_off (NautilusWindow *window)
 		next = l->next;
 		pane = l->data;
 		if (pane != active_pane) {
-			nautilus_window_close_pane (pane);
+			nautilus_window_close_pane (window, pane);
 		}
 	}
 
